@@ -2,7 +2,7 @@ import struct
 from typing import NamedTuple, Optional, List, Union
 
 from bxcommon import constants
-from bxcommon.models.quota_type_model import QuotaType
+from bxcommon.models.transaction_flag import TransactionFlag
 from bxcommon.utils.crypto import SHA256_HASH_LEN
 from bxcommon.utils.object_hash import Sha256Hash
 from bxutils import logging
@@ -14,7 +14,7 @@ class TxContentShortIds(NamedTuple):
     tx_hash: Sha256Hash
     tx_content: Optional[Union[bytearray, memoryview]]
     short_ids: List[int]
-    short_id_flags: List[QuotaType]
+    short_id_flags: List[TransactionFlag]
 
 
 def get_serialized_tx_content_short_ids_bytes_len(tx_content_short_ids: TxContentShortIds) -> int:
@@ -36,7 +36,7 @@ def get_serialized_tx_content_short_ids_bytes_len(tx_content_short_ids: TxConten
         tx_content_size = len(tx_content_short_ids.tx_content)
 
     return SHA256_HASH_LEN + constants.UL_INT_SIZE_IN_BYTES + tx_content_size + constants.UL_INT_SIZE_IN_BYTES + \
-        constants.UL_SHORT_SIZE_IN_BYTES + (constants.SID_LEN + constants.QUOTA_FLAG_LEN) * short_ids_count
+        constants.UL_SHORT_SIZE_IN_BYTES + (constants.SID_LEN + constants.TRANSACTION_FLAG_LEN) * short_ids_count
 
 
 def get_serialized_txs_content_short_ids_bytes_len(txs_content_short_ids: List[TxContentShortIds]) -> int:
@@ -84,15 +84,16 @@ def serialize_txs_content_short_ids_into_bytes(
                 struct.pack_into("<L", buffer, off, short_id)
                 off += constants.SID_LEN
 
-            # we pass a quota flags for each short id provided
+            # we pass a transaction flags for each short id provided
             # we pass an array of flags following the array of short ids, in matching order
-            # we require that quota flags array to be the same length of the short_ids array,
-            # if validation fail, we will pass empty values as the quota flags, to make backwards compatibility easier.
+            # we require that transaction flags array to be the same length of the short_ids array,
+            # if validation fail, we will pass empty values as the transaction flags,
+            # to make backwards compatibility easier.
             assert len(tx_content_short_ids.short_id_flags) == len(tx_content_short_ids.short_ids),\
-                "Invalid QuotaFlag Array Provided"
-            for short_id_quota_type in tx_content_short_ids.short_id_flags:
-                struct.pack_into("<B", buffer, off, short_id_quota_type.value)
-                off += constants.QUOTA_FLAG_LEN
+                "Invalid TransactionFlag Array Provided"
+            for short_id_tx_flag in tx_content_short_ids.short_id_flags:
+                struct.pack_into("<H", buffer, off, short_id_tx_flag.value)
+                off += constants.TRANSACTION_FLAG_LEN
 
         else:
             logger.debug(
@@ -135,9 +136,9 @@ def deserialize_txs_content_short_ids_from_buffer(
             short_ids.append(short_id)
             offset += constants.SID_LEN
         for _ in range(short_ids_count):
-            short_id_flag, = struct.unpack_from("<B", buffer, offset)
-            short_id_flags.append(QuotaType(short_id_flag))
-            offset += constants.QUOTA_FLAG_LEN
+            short_id_flag, = struct.unpack_from("<H", buffer, offset)
+            short_id_flags.append(TransactionFlag(short_id_flag))
+            offset += constants.TRANSACTION_FLAG_LEN
         txs_content_short_ids.append(TxContentShortIds(tx_hash, tx_content, short_ids, short_id_flags))
 
     return txs_content_short_ids
