@@ -1,6 +1,6 @@
 from typing import Optional
 
-import rlp
+import blxr_rlp as rlp
 
 from bxcommon.utils.blockchain_utils.eth import eth_common_constants
 
